@@ -1,3 +1,7 @@
+from __future__ import (
+    unicode_literals, print_function, absolute_import, with_statement
+)
+
 import _ast
 from os import path as op, environ
 
